@@ -200,7 +200,7 @@ sub clone {
 
 sub _new_from_chunk {
     my $class = shift;
-    my $chunk = shift or return;
+    my $chunk = shift or return;    # 512 bytes of tar header
     my %hash  = @_;
 
     ### filter any arguments on defined-ness of values.
@@ -233,18 +233,34 @@ sub _new_from_chunk {
 
 sub _new_from_file {
     my $class       = shift;
-    my $path        = shift or return;
+    my $path        = shift;        
+    
+    ### path has to at least exist
+    return unless defined $path;
+    
     my $type        = __PACKAGE__->_filetype($path);
     my $data        = '';
 
-    unless ($type == DIR || $type == SYMLINK) {
-        my $fh = IO::File->new;
-        $fh->open($path) or return;
+    READ: { 
+        unless ($type == DIR ) {
+            my $fh = IO::File->new;
+        
+            unless( $fh->open($path) ) {
+                ### dangling symlinks are fine, stop reading but continue
+                ### creating the object
+                last READ if $type == SYMLINK;
+                
+                ### otherwise, return from this function --
+                ### anything that's *not* a symlink should be
+                ### resolvable
+                return;
+            }
 
-        ### binmode needed to read files properly on win32 ###
-        binmode $fh;
-        $data = do { local $/; <$fh> };
-        close $fh;
+            ### binmode needed to read files properly on win32 ###
+            binmode $fh;
+            $data = do { local $/; <$fh> };
+            close $fh;
+        }
     }
 
     my @items       = qw[mode uid gid size mtime];
@@ -292,7 +308,7 @@ sub _new_from_file {
 
 sub _new_from_data {
     my $class   = shift;
-    my $path    = shift     or return;
+    my $path    = shift;    return unless defined $path;
     my $data    = shift;    return unless defined $data;
     my $opt     = shift;
 
@@ -359,7 +375,9 @@ sub _prefix_and_file {
 
 sub _filetype {
     my $self = shift;
-    my $file = shift or return;
+    my $file = shift;
+    
+    return unless defined $file;
 
     return SYMLINK  if (-l $file);	# Symlink
 
@@ -503,7 +521,9 @@ Returns true on success and false on failure.
 
 sub rename {
     my $self = shift;
-    my $path = shift or return;
+    my $path = shift;
+    
+    return unless defined $path;
 
     my ($prefix,$file) = $self->_prefix_and_file( $path );
 
